==> packagesearch_2.5.tar.gz: packagesearch-2.5/translations/filenameplugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>FilenameFeedbackWidget</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenamefeedbackwidget.ui" line="13"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenamefeedbackwidget.ui" line="25"/>
        <source>Search for filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenamefeedbackwidget.ui" line="40"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenamefeedbackwidget.ui" line="47"/>
        <source>Shows the filename that was searched for</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FilenameSearchInput</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenamesearchinput.ui" line="13"/>
        <source>Form1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenamesearchinput.ui" line="25"/>
        <source>Search packages with files containing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenamesearchinput.ui" line="32"/>
        <source>Search packages containing a file whose filename matches the pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenamesearchinput.ui" line="39"/>
        <source>Check this if you want to search only the installed packages (usually much faster)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenamesearchinput.ui" line="42"/>
        <source>search installed packages only</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FilenameView</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="51"/>
        <source>Trying to view </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="56"/>
        <source> not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="57"/>
        <source>The &lt;tt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="59"/>
        <source>&lt;/tt&gt; command is not available.
Please make sure that the &lt;tt&gt;mime-support&lt;/tt&gt; package is installed and that you have permission to execute &lt;tt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="60"/>
        <source>&lt;/tt&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="71"/>
        <source>Unable to launch </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="72"/>
        <source>Launching &lt;tt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="73"/>
        <source>&lt;/tt&gt; failed due to an unknown reason.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="95"/>
        <source>Error viewing file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="95"/>
        <source>Unable to view file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="96"/>
        <source>
Tried &lt;tt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="96"/>
        <source>&lt;/tt&gt; and
&lt;tt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="103"/>
        <source>Retrying to view </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="103"/>
        <source> with mimetype text/plain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="114"/>
        <source>Finished viewing </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="130"/>
        <source>Can&apos;t view file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="130"/>
        <source>, it is not viewable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="153"/>
        <source>Copy to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="154"/>
        <source>Copy all filenames to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="155"/>
        <source>View file (depends on settings in /etc/mailcap)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.ui" line="13"/>
        <source>Form1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.ui" line="33"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.ui" line="40"/>
        <source>Filter files to be shown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.ui" line="47"/>
        <source>Show the filelist for the selected package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.ui" line="50"/>
        <source>Shows a list of the files which are included in the package. If the list is already shown it will be updated.&lt;br&gt;
For installed packages the list is shown by default because it is quite fast. For not installed package it is only shown if this button is clicked as it takes a considerable amount of time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.ui" line="54"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::FilenameActionPlugin</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameactionplugin.cpp" line="29"/>
        <source>Calls &quot;apt-file update&quot; updating the file database</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::FilenamePlugin</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="66"/>
        <source>Filename Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="71"/>
        <source>Plugin to search by files and diplay files in packages.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="78"/>
        <source>This plugin allows to search the packages for files, and to display the files included in the packages
For information about not installed packages, it needs the &lt;tt&gt;apt-file&lt;/tt&gt; tool.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="115"/>
        <source>Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="140"/>
        <source>&lt;font color=#606060&gt;For packages &lt;b&gt;not installed&lt;/b&gt;, the file list is not shown by default. This is because retreiving the file list will take some time.&lt;br&gt;Please click the &lt;b&gt;&amp;quot;Show&amp;quot;&lt;/b&gt; button to show the filelist for the selected package.&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="178"/>
        <source>Filenames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="237"/>
        <source>Querying database for file list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="278"/>
        <source>There is no file information for the current package available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="308"/>
        <source>delayed evaluation - waiting for further input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="326"/>
        <source>Apt file search not availabe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="331"/>
        <source>You need the &lt;tt&gt;apt-file&lt;/tt&gt; utility to search files in packages not installed.&lt;br&gt;To get apt-file fetch it via &lt;tt&gt;apt-get install apt-file&lt;/tt&gt; and run &lt;tt&gt;apt-file update&lt;/tt&gt; afterwards.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="340"/>
        <source>Performing search for filenames, this might take a while</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="417"/>
        <source>&lt;font color=#606060&gt;&lt;p&gt;File list for &lt;b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="420"/>
        <source>&lt;/b&gt; not available.&lt;/p&gt;&lt;p&gt;For displaying the file list for not-installed packages, the &quot;apt-file&quot; package is required. Please install &quot;apt-file&quot; and retrieve the latest file database by running  &lt;tt&gt;apt-file update&lt;/tt&gt;.&lt;/p&gt;&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::FilenamePluginContainer</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugincontainer.cpp" line="112"/>
        <source>Command not executed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugincontainer.cpp" line="104"/>
        <source>For an unknwon reason, the command could not be executed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugincontainer.cpp" line="124"/>
        <source>Update not successfully completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugincontainer.cpp" line="127"/>
        <source>The apt-file update was not completed successfully.&lt;br&gt;The database might be broken, rerun &lt;tt&gt;apt-file update&lt;/tt&gt; to fix this.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameactionplugin.cpp" line="28"/>
        <source>Update File Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugincontainer.cpp" line="83"/>
        <source>Filename Plugins</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> packagesearch_2.6.tar.gz: packagesearch-2.6/translations/filenameplugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>FilenameView</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="51"/>
        <source>Trying to view </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="56"/>
        <source> not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="57"/>
        <source>The &lt;tt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="57"/>
        <source>&lt;/tt&gt; command is not available.
Please make sure that the &lt;tt&gt;mime-support&lt;/tt&gt; package is installed and that you have permission to execute &lt;tt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="59"/>
        <source>&lt;/tt&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="71"/>
        <source>Unable to launch </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="72"/>
        <source>Launching &lt;tt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="72"/>
        <source>&lt;/tt&gt; failed due to an unknown reason.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="95"/>
        <source>Error viewing file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="95"/>
        <source>Unable to view file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="96"/>
        <source>
Tried &lt;tt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="96"/>
        <source>&lt;/tt&gt; and
&lt;tt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="103"/>
        <source>Retrying to view </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="103"/>
        <source> with mimetype text/plain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="114"/>
        <source>Finished viewing </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="130"/>
        <source>Can&apos;t view file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="130"/>
        <source>, it is not viewable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="153"/>
        <source>Copy to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="154"/>
        <source>Copy all filenames to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameview.cpp" line="155"/>
        <source>View file (depends on settings in /etc/mailcap)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::FilenameActionPlugin</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameactionplugin.cpp" line="29"/>
        <source>Calls &quot;apt-file update&quot; updating the file database</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::FilenamePlugin</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="66"/>
        <source>Filename Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="71"/>
        <source>Plugin to search by files and diplay files in packages.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="76"/>
        <source>This plugin allows to search the packages for files, and to display the files included in the packages
For information about not installed packages, it needs the &lt;tt&gt;apt-file&lt;/tt&gt; tool.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="115"/>
        <source>Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="136"/>
        <source>&lt;font color=#606060&gt;For packages &lt;b&gt;not installed&lt;/b&gt;, the file list is not shown by default. This is because retreiving the file list will take some time.&lt;br&gt;Please click the &lt;b&gt;&amp;quot;Show&amp;quot;&lt;/b&gt; button to show the filelist for the selected package.&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="178"/>
        <source>Filenames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="237"/>
        <source>Querying database for file list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="278"/>
        <source>There is no file information for the current package available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="308"/>
        <source>delayed evaluation - waiting for further input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="326"/>
        <source>Apt file search not availabe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="327"/>
        <source>You need the &lt;tt&gt;apt-file&lt;/tt&gt; utility to search files in packages not installed.&lt;br&gt;To get apt-file fetch it via &lt;tt&gt;apt-get install apt-file&lt;/tt&gt; and run &lt;tt&gt;apt-file update&lt;/tt&gt; afterwards.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="340"/>
        <source>Performing search for filenames, this might take a while</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="417"/>
        <source>&lt;font color=#606060&gt;&lt;p&gt;File list for &lt;b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugin.cpp" line="417"/>
        <source>&lt;/b&gt; not available.&lt;/p&gt;&lt;p&gt;For displaying the file list for not-installed packages, the &quot;apt-file&quot; package is required. Please install &quot;apt-file&quot; and retrieve the latest file database by running  &lt;tt&gt;apt-file update&lt;/tt&gt;.&lt;/p&gt;&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::FilenamePluginContainer</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugincontainer.cpp" line="103"/>
        <location filename="../src/plugins/filenameplugin/filenameplugincontainer.cpp" line="112"/>
        <source>Command not executed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugincontainer.cpp" line="103"/>
        <source>For an unknwon reason, the command could not be executed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugincontainer.cpp" line="124"/>
        <source>Update not successfully completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugincontainer.cpp" line="125"/>
        <source>The apt-file update was not completed successfully.&lt;br&gt;The database might be broken, rerun &lt;tt&gt;apt-file update&lt;/tt&gt; to fix this.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameactionplugin.cpp" line="28"/>
        <source>Update File Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/filenameplugin/filenameplugincontainer.cpp" line="83"/>
        <source>Filename Plugins</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
